Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(200)

Unified Diff: ios/web_view/internal/web_view_url_request_context_getter.h

Issue 2715043002: Replace prefix of ios/web_view C++ classes. (Closed)
Patch Set: Respond to comments. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/web_view/internal/web_view_url_request_context_getter.h
diff --git a/ios/web_view/internal/criwv_url_request_context_getter.h b/ios/web_view/internal/web_view_url_request_context_getter.h
similarity index 78%
rename from ios/web_view/internal/criwv_url_request_context_getter.h
rename to ios/web_view/internal/web_view_url_request_context_getter.h
index 78150f4a253b6ca6645f43602703810ce1c1fdac..c82c8d4c8ca4acf3a2d67fc1d0591b66cce55170 100644
--- a/ios/web_view/internal/criwv_url_request_context_getter.h
+++ b/ios/web_view/internal/web_view_url_request_context_getter.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IOS_WEB_VIEW_INTERNAL_CRIWV_URL_REQUEST_CONTEXT_GETTER_H_
-#define IOS_WEB_VIEW_INTERNAL_CRIWV_URL_REQUEST_CONTEXT_GETTER_H_
+#ifndef IOS_WEB_VIEW_INTERNAL_WEB_VIEW_URL_REQUEST_CONTEXT_GETTER_H_
+#define IOS_WEB_VIEW_INTERNAL_WEB_VIEW_URL_REQUEST_CONTEXT_GETTER_H_
#include <memory>
#include "base/compiler_specific.h"
@@ -23,10 +23,10 @@ class URLRequestContextStorage;
namespace ios_web_view {
-// CWV-specific implementation of URLRequestContextGetter.
-class CRIWVURLRequestContextGetter : public net::URLRequestContextGetter {
+// WebView implementation of URLRequestContextGetter.
+class WebViewURLRequestContextGetter : public net::URLRequestContextGetter {
public:
- CRIWVURLRequestContextGetter(
+ WebViewURLRequestContextGetter(
const base::FilePath& base_path,
const scoped_refptr<base::SingleThreadTaskRunner>& network_task_runner,
const scoped_refptr<base::SingleThreadTaskRunner>& file_task_runner,
@@ -38,7 +38,7 @@ class CRIWVURLRequestContextGetter : public net::URLRequestContextGetter {
const override;
protected:
- ~CRIWVURLRequestContextGetter() override;
+ ~WebViewURLRequestContextGetter() override;
private:
base::FilePath base_path_;
@@ -53,9 +53,9 @@ class CRIWVURLRequestContextGetter : public net::URLRequestContextGetter {
std::unique_ptr<net::TransportSecurityPersister>
transport_security_persister_;
- DISALLOW_COPY_AND_ASSIGN(CRIWVURLRequestContextGetter);
+ DISALLOW_COPY_AND_ASSIGN(WebViewURLRequestContextGetter);
};
} // namespace ios_web_view
-#endif // IOS_WEB_VIEW_INTERNAL_CRIWV_URL_REQUEST_CONTEXT_GETTER_H_
+#endif // IOS_WEB_VIEW_INTERNAL_WEB_VIEW_URL_REQUEST_CONTEXT_GETTER_H_
« no previous file with comments | « ios/web_view/internal/web_view_network_delegate.cc ('k') | ios/web_view/internal/web_view_url_request_context_getter.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698